.. include:: /_includes/wip_prolog.rst

:mod:`stix.common.kill_chains` Module
=====================================

.. module:: stix.common.kill_chains

Classes
-------

.. autoclass:: KillChain
	:show-inheritance:
	:members:

.. autoclass:: KillChains
	:show-inheritance:
	:members:

.. autoclass:: KillChainPhase
	:show-inheritance:
	:members:

.. autoclass:: KillChainPhaseReference
	:show-inheritance:
	:members:

.. autoclass:: KillChainPhasesReference
	:show-inheritance:
	:members:
